@@ -2,7 +2,7 @@ from Products.PurgeMissingObjectInterfaces import cleaner
 from FakeZopeInterface.FakeZopeInterface import check_importable
 import pprint, StringIO
 
-def find(self, string='p4a', target='plone'):
+def find(self, string='p4a,dateable,JunkInterface', target='plone'):
     context = self[target]
     strings = string.split(',')
     count = 0
